import { Dialog, DialogBackdrop, DialogPanel } from '@headlessui/react';

export default function Modal({ isOpen, onClose, title = '', children }) {
    if (!isOpen) return null;

    return (
        <Dialog open={isOpen} onClose={onClose} className="relative z-[999]">
            <DialogBackdrop
                transition
                className="fixed inset-0 bg-bg-dark transition-opacity data-[closed]:opacity-0 data-[enter]:duration-300 data-[leave]:duration-200 data-[enter]:ease-out data-[leave]:ease-in backdrop-blur-md bg-opacity-80"
            />

            <div className="fixed inset-0 z-10 w-screen overflow-y-auto">
                <div className="lg:flex min-h-full items-end justify-center p-4 text-center sm:items-center sm:p-0">
                    <DialogPanel
                        transition
                        className="relative transform rounded-2xl bg-bg-dark text-left shadow-xl transition-all data-[closed]:translate-y-4 data-[closed]:opacity-0 data-[enter]:duration-300 data-[leave]:duration-200 data-[enter]:ease-out data-[leave]:ease-in sm:my-8 sm:w-full sm:max-w-lg data-[closed]:sm:translate-y-0 data-[closed]:sm:scale-95 border border-opacity-50 border-border bg-background-secondary"
                    >
                        <div className="bg-bg-dark px-4 pb-4 pt-5 sm:p-6 sm:pb-4">
                            <div className='flex justify-between items-center'>
                                <h3 className="font-bold text-gray-100 text-lg">{title}</h3>

                                <button type="button" onClick={onClose} className="justify-center rounded-md text-gray-900 ">
                                    <i className="bi bi-x-lg text-text-primary hover:text-text-white"></i>
                                </button>
                            </div>

                            {children}
                        </div>
                    </DialogPanel>
                </div>
            </div>
        </Dialog>
    )
}
